# Statistical Distribution implemementation
The main purpose of this package is testing, mainly test how to manage packages in python.

# Vielinko Distribution
The package is called vielinko_dist and contains Gaussian and Binomial simple implementation

# How to use it?
under construction

# Examples
under construction

# License
MIT licence.